#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-6w7l3MFr3s5GGmPeFyak7n
key:                  ghcide-2.3.0.0-6w7l3MFr3s5GGmPeFyak7n
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  d49391c89f7590238befceccb9ab37d0
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-6w7l3MFr3s5GGmPeFyak7n
depends:
    Diff-0.5-DDcCy92IExfCtRvJQXZSWB Glob-0.10.2-GEgZ9FtLCTE3gilAVS8w1V
    aeson-2.2.1.0-7GSyYSIvS9RDNhRsQEr5uY array-0.5.6.0
    async-2.2.6-8zdvXX2Zsrb75FFkoyfONv base-4.18.2.1
    base16-bytestring-1.0.2.0-pqJwJeshH1IdI5VXEk8FQ binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-JZ3hGp6UuW4CjEwd4EXTon
    co-log-core-0.3.2.6-5Hx4M7Tck694Pit0LVcvQK containers-0.6.7
    cryptohash-sha1-0.11.101.0-G8w7Wc1b4UEHVy78nb80eR
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-48oozOVbcXVDVSPUJGC8bH
    dependent-sum-0.7.2.0-HnczrmMjww9HzVmv6MoBtv directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-5SKFhlgia1b22y2Pp2iCUf exceptions-0.10.7
    extra-1.7.16-78rWMJMvfkTD1P7HRrGqSG filepath-1.4.300.1
    fingertree-0.1.6.2-GA7n0XY33lH7aehnjDlh8V
    focus-1.0.3.2-3TbsV08S0Oi6S6zLQFw2F6 ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-IMmtjyyrSb61UuWxQsGr43
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-GK2GN3ZJ5rZFtwU2clg6Hv
    hashable-1.4.7.0-7IXYIAIJ1Hk6CRw3icGaw3
    hie-bios-0.12.0-Go20lGxKPPZDuI66ar7jZX
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-1M3fPIp8Bux9vFwLxerRYA
    hls-graph-2.3.0.0-65WRushYxdZ4YlcNcFbBXT
    hls-plugin-api-2.3.0.0-LfFc7Z03YyoGYY0VVD4QTJ
    implicit-hie-0.1.4.0-K8EmaPLUEDaCkIDDFu28Dw
    implicit-hie-cradle-0.5.0.1-9mAHnfJUWLo4HBok4i7r0C
    lens-5.3.4-Cku8S685vSJvKBRP2wLkQ
    list-t-1.0.5.7-IWEuNBW88KjGDBl2MqELW6
    lsp-2.2.0.0-6LZ7pOCDgZ2AzF4Z9mZdB3
    lsp-types-2.0.2.0-xmc6WCw8XEoIKXtrPVFU mtl-2.3.1
    opentelemetry-0.8.0-7xXJLzkNEUmAbAM3N5TGv2
    optparse-applicative-0.18.1.0-1hpBcyZ9dkK8RGPfmI5i3r
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-AIpSGHD2G4p9DIqum0FCg8
    prettyprinter-ansi-terminal-1.1.3-9nCwTFmnkkuDeMiCSbsjin
    random-1.2.1.3-1X0iumC2zGHGNw6mS2AiRE
    regex-tdfa-1.3.2.5-64vlZfKQDaw2d9qr96tjvC
    row-types-1.0.1.2-GVywpg0ndquKQRKjxYz33
    safe-exceptions-0.1.7.4-Cn5kfaxd0fGJ7b6k9JieJx
    sorted-list-0.2.3.1-3mf2bfDqITKDsG7xcRm3ux
    sqlite-simple-0.4.19.0-5IuZa8Rs010JGS1nfgvvQt stm-2.5.1.0
    stm-containers-1.2.1.1-DW8ki2zRufP9TvIgdJkX6o
    syb-0.7.3-GOgVLrICGxz57uuYen0TbH text-2.0.2
    text-rope-0.3-Ap9tNAElwvo1DE9nQl4uAS time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-JnhUHQXeGEX5efNIWb5EqF
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-KOOMDe69vyW5LNgLyOaup0
    vector-0.13.2.0-HarLsKOX3fDLjvAK8O9pTy

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

